
/**
 * @file
 * Scrolling script for our block.
 */

(function($) {
  
  var ucPicCartSetCookie = function(name, value) {
    $.cookie(name, value, {
      path: Drupal.settings.basePath
    });
  }
  
  var initUcPicCartScroll = function() {
      var scrollArea = $("#uc_pic_cart_block_scroll_area");
      var contentArea = $("#uc_pic_cart_block_content");
      var newHeight = 0;
      var delta = 0;
      var cook = $.cookie('ucPicCartBlockScrollPos');
      
      if (Drupal.settings.ucPicCartBlockOrientation == 0) {
        // Average height of items multiplied by scroll count
        newHeight = contentArea.height() / Drupal.settings.ucPicCartBlockProductCount * Drupal.settings.ucPicCartBlockScrollCount;
        delta = $(".qty:last", contentArea).height(); // height of row with count and sum
        
        var arrowUp = $("#uc_pic_cart_block_scroll_up");
        var arrowDown = $("#uc_pic_cart_block_scroll_down");
        
        scrollArea.addClass("uc_pic_cart_block_scroll_area_vert");
        $(".uc_pic_cart_block_scroll_up_def").removeClass("uc_pic_cart_block_scroll_up_def").addClass("uc_pic_cart_block_scroll_up_scroll");
        $(".uc_pic_cart_block_scroll_down_def").removeClass("uc_pic_cart_block_scroll_down_def").addClass("uc_pic_cart_block_scroll_down_scroll");
        scrollArea.height(newHeight);
        if (cook) {
            scrollArea.scrollTop(cook);
        }
        
        arrowUp.click(function () {
          scrollArea.scrollTop(scrollArea.scrollTop() - delta);
          ucPicCartSetCookie('ucPicCartBlockScrollPos', scrollArea.scrollTop());
        });

        arrowDown.click(function () {
          scrollArea.scrollTop(scrollArea.scrollTop() + delta);
          ucPicCartSetCookie('ucPicCartBlockScrollPos', scrollArea.scrollTop());
        });
      }
      else {
        var div = $("div.uc_pic_cart_block_item_hor");
        var wdt = 0;
        var newHeight = 0;
        var iwdt = 0;
        
        div.each(function() {
            // get max width, outer width and outer height of cart items
            var el = $(this);
            var ow = el.outerWidth(true);
            var iw = el.width();
            var hg = el.outerHeight(true);
            if (ow > wdt) {
                wdt = ow;
            }
            if (iw > iwdt) {
                iwdt = iw;
            }
            if (hg > newHeight) {
                newHeight = hg;
            }
        });
        
        var wdtNeed = (wdt + 2) * Drupal.settings.ucPicCartBlockProductCount;
        if (wdtNeed < scrollArea.width()) {
            return;
        }
        
        delta = wdt / 2;
        
        var arrowLeft = $("#uc_pic_cart_block_scroll_left");
        var arrowRight = $("#uc_pic_cart_block_scroll_right");
        
        
        scrollArea.addClass("uc_pic_cart_block_scroll_area_hor");
        contentArea.height(newHeight);
        contentArea.width(wdtNeed);
        div.width(iwdt);
        
        if ($(".uc_pic_cart_block_scroll_left_def").length || $(".uc_pic_cart_block_scroll_right_def").length) {
            // Default (Garland)
            $(".uc_pic_cart_block_scroll_left_def").height(newHeight).removeClass("uc_pic_cart_block_scroll_left_def").addClass("uc_pic_cart_block_scroll_left_scroll");
            var img = $("img", arrowLeft);
            img.css({position : 'relative', top : newHeight / 2 - img.height()});
        
            $(".uc_pic_cart_block_scroll_right_def").height(newHeight).removeClass("uc_pic_cart_block_scroll_right_def").addClass("uc_pic_cart_block_scroll_right_scroll");
            img = $("img", arrowRight);
            img.css({'position' : 'relative', 'top' : newHeight / 2 - img.height()});
            
            // setting absolute position and width - need for crossbrowsing :(
            var lft = arrowLeft.position().left + arrowLeft.outerWidth(true) + 1;
            var wdtBlock = arrowRight.position().left - lft - arrowRight.outerWidth(true) + arrowRight.innerWidth() + 1;
            scrollArea.css({position : "absolute", top : arrowLeft.position().top, left : lft});
            scrollArea.width(wdtBlock);
        }
        
        if (cook) {
          scrollArea.scrollLeft(cook);
        }
        
        arrowLeft.click(function () {
          scrollArea.scrollLeft(scrollArea.scrollLeft() - delta);
          ucPicCartSetCookie('ucPicCartBlockScrollPos', scrollArea.scrollLeft());
        });

        arrowRight.click(function () {
          scrollArea.scrollLeft(scrollArea.scrollLeft() + delta);
          ucPicCartSetCookie('ucPicCartBlockScrollPos', scrollArea.scrollLeft());
        });
      }
  }
  
  Drupal.behaviors.ucPicCartBlockScrolling = {
    attach: function(context, settings) {
      if ($('#uc-pic-cart-block-wrapper', context).hasClass('ucPicCartBlockScrolling-processed')) {
        return;
      };
      // jQuery.once not working as expected???
      $('#uc-pic-cart-block-wrapper', context).addClass('ucPicCartBlockScrolling-processed');
      if (settings.ucPicCartBlockUseScroll) {
        initUcPicCartScroll();
      }
      else {
        ucPicCartSetCookie('ucPicCartBlockScrollPos', 0);
      }
    }
  };
  
})(jQuery)